@@ -107,6 +107,11 @@
 
 #include "gioalias.h"
 
+/* See gstdio.h */
+#ifndef G_OS_WIN32
+#define _g_stat_struct stat
+#endif
+
 static void g_local_file_file_iface_init (GFileIface *iface);
 
 static GFileAttributeInfoList *local_writable_attributes = NULL;
@@ -742,7 +747,7 @@ get_mount_info (GFileInfo             *fs_info,
 		const char            *path,
 		GFileAttributeMatcher *matcher)
 {
-  struct stat buf;
+  struct _g_stat_struct buf;
   gboolean got_info;
   gpointer info_as_ptr;
   guint mount_info;
@@ -1053,7 +1058,7 @@ g_local_file_find_enclosing_mount (GFile         *file,
                                    GError       **error)
 {
   GLocalFile *local = G_LOCAL_FILE (file);
-  struct stat buf;
+  struct _g_stat_struct buf;
   char *mountpoint;
   GMount *mount;
 
@@ -1099,7 +1104,9 @@ g_local_file_set_display_name (GFile         *file,
 {
   GLocalFile *local, *new_local;
   GFile *new_file, *parent;
-  struct stat statbuf;
+  struct _g_stat_struct statbuf;
+  GVfsClass *class;
+  GVfs *vfs;
   int errsv;
 
   parent = g_file_get_parent (file);
@@ -1158,7 +1165,12 @@ g_local_file_set_display_name (GFile         *file,
       g_object_unref (new_file);
       return NULL;
     }
-  
+
+  vfs = g_vfs_get_default ();
+  class = G_VFS_GET_CLASS (vfs);
+  if (class->local_file_moved)
+    class->local_file_moved (vfs, local->filename, new_local->filename);
+
   return new_file;
 }
 
@@ -1510,7 +1522,7 @@ get_parent (const char *path,
             dev_t      *parent_dev)
 {
   char *parent, *tmp;
-  struct stat parent_stat;
+  struct _g_stat_struct parent_stat;
   int num_recursions;
   char *path_copy;
 
@@ -1719,12 +1731,12 @@ _g_local_file_has_trash_dir (const char *dirname, dev_t dir_dev)
   char *topdir, *globaldir, *trashdir, *tmpname;
   uid_t uid;
   char uid_str[32];
-  struct stat global_stat, trash_stat;
+  struct _g_stat_struct global_stat, trash_stat;
   gboolean res;
 
   if (g_once_init_enter (&home_dev_set))
     {
-      struct stat home_stat;
+      struct _g_stat_struct home_stat;
 
       g_stat (g_get_home_dir (), &home_stat);
       home_dev = home_stat.st_dev;
@@ -1786,7 +1798,7 @@ g_local_file_trash (GFile         *file,
 		    GError       **error)
 {
   GLocalFile *local = G_LOCAL_FILE (file);
-  struct stat file_stat, home_stat;
+  struct _g_stat_struct file_stat, home_stat;
   const char *homedir;
   char *trashdir, *topdir, *infodir, *filesdir;
   char *basename, *trashname, *trashfile, *infoname, *infofile;
@@ -1796,9 +1808,11 @@ g_local_file_trash (GFile         *file,
   gboolean is_homedir_trash;
   char delete_time[32];
   int fd;
-  struct stat trash_stat, global_stat;
+  struct _g_stat_struct trash_stat, global_stat;
   char *dirname, *globaldir;
-  
+  GVfsClass *class;
+  GVfs *vfs;
+
   if (g_lstat (local->filename, &file_stat) != 0)
     {
       int errsv = errno;
@@ -2021,6 +2035,11 @@ g_local_file_trash (GFile         *file,
       return FALSE;
     }
 
+  vfs = g_vfs_get_default ();
+  class = G_VFS_GET_CLASS (vfs);
+  if (class->local_file_moved)
+    class->local_file_moved (vfs, local->filename, trashfile);
+
   g_free (trashfile);
 
   /* TODO: Do we need to update mtime/atime here after the move? */
@@ -2190,7 +2209,7 @@ g_local_file_move (GFile                  *source,
 		   GError                **error)
 {
   GLocalFile *local_source, *local_destination;
-  struct stat statbuf;
+  struct _g_stat_struct statbuf;
   gboolean destination_exist, source_is_dir;
   char *backup_name;
   int res;
